@@ -127,7 +127,7 @@ void MultiplechoiceModeWidget::setNumberOfRadioButtons(const int numberOfChoices
         if (i < 5) {
             connect(m_actions.at(i), SIGNAL(triggered()), radio_button, SLOT(click()));
         }
-        connect(radio_button, SIGNAL(clicked()), this, SIGNAL(continueAction()));
+        connect(radio_button, &QRadioButton::clicked, this, &MultiplechoiceModeWidget::continueAction);
         radio_button->installEventFilter(this);
     }
 }
